@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2025-07-24 21:51:42
+@LastEditTime: 2025-08-05 15:53:24
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -215,9 +215,26 @@ class AssetBaseModel():
                 member_asset_log.valid_type = 1
             member_asset_log.create_date = now_datetime
 
+            update_asset_log_list = []
+            if operate_type in [1, 3]: # 只有消费和作废需要，更新剩余值
+                asset_log_list = member_asset_log_model.get_list(where="one_id=%s AND asset_type=1 AND operate_type=0 AND surplus_value>0", params=[one_id], order_by="valid_end_date ASC,create_date ASC")
+                operate_value = asset_value
+                for asset_log in asset_log_list:
+                    if asset_log.surplus_value >= operate_value:
+                        asset_log.history_value = asset_log.surplus_value  # 历史值为当前剩余值
+                        asset_log.surplus_value -= operate_value  # 剩余值减少
+                        update_asset_log_list.append(asset_log)
+                        break
+                    else:
+                        asset_log.history_value = asset_log.surplus_value  # 历史值为当前剩余值
+                        operate_value -= asset_log.surplus_value  # 操作值减少
+                        asset_log.surplus_value = 0  # 剩余值为0
+                        update_asset_log_list.append(asset_log)
 
             # 开始事务
             db_transaction.begin_transaction()
+            if update_asset_log_list:
+                member_asset_log_model.update_list(update_asset_log_list, field_list='history_value,surplus_value')
 
             if old_user_asset_id != 0:
                 member_asset_model.update_entity(member_asset, "asset_value,asset_check_code,modify_date,total_incr_value,total_decr_value")
